@@ -6,10 +6,13 @@
 from __future__ import annotations
 
 import sys
-from typing import Callable
+from typing import TYPE_CHECKING
 
 from anta import __DEBUG__
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
 # Note: need to separate this file from _main to be able to fail on the import.
 try:
     from ._main import anta, cli
@@ -24,11 +27,12 @@ except ImportError as exc:
             if not exception.name or "click" not in exception.name:
                 raise exception
 
-            print(
+            msg = (
                 "The ANTA command line client could not run because the required "
                 "dependencies were not installed.\nMake sure you've installed "
                 "everything with: pip install 'anta[cli]'"
             )
+            print(msg)
             if __DEBUG__:
                 print(f"The caught exception was: {exception}")
 
