@@ -7,19 +7,23 @@ from __future__ import annotations
 
 import functools
 import logging
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any, TypeVar
 
 import click
 
 from anta.cli.utils import ExitCode, core_options
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from anta.inventory import AntaInventory
 
 logger = logging.getLogger(__name__)
 
+R = TypeVar("R")
 
-def debug_options(f: Callable[..., Any]) -> Callable[..., Any]:
+
+def debug_options(f: Callable[..., R]) -> Callable[..., R]:
     """Click common options required to execute a command on a specific device."""
 
     @core_options
@@ -42,15 +46,13 @@ def debug_options(f: Callable[..., Any]) -> Callable[..., Any]:
     @functools.wraps(f)
     def wrapper(
         ctx: click.Context,
-        *args: tuple[Any],
         inventory: AntaInventory,
         device: str,
-        **kwargs: Any,
-    ) -> Any:
-        # TODO: @gmuloc - tags come from context https://github.com/aristanetworks/anta/issues/584
+        **kwargs: Any,  # noqa: ANN401
+    ) -> R:
         if (d := inventory.get(device)) is None:
             logger.error("Device '%s' does not exist in Inventory", device)
             ctx.exit(ExitCode.USAGE_ERROR)
-        return f(*args, device=d, **kwargs)
+        return f(device=d, **kwargs)
 
     return wrapper
