@@ -35,10 +35,19 @@ logger = logging.getLogger(__name__)
     help="Sort test results.",
     required=False,
 )
-def table(ctx: click.Context, group_by: Literal["device", "test"] | None, sort_by: tuple[str] | None) -> None:
+@click.option(
+    "--expand",
+    "-x",
+    default=False,
+    show_envvar=True,
+    is_flag=True,
+    show_default=True,
+    help="Flag to indicate if atomic results should be shown.",
+)
+def table(ctx: click.Context, *, group_by: Literal["device", "test"] | None, sort_by: tuple[str] | None, expand: bool) -> None:
     """ANTA command to check network state with table results."""
     _ = run_tests(ctx)
-    print_table(ctx, group_by=group_by, sort_by=sort_by)
+    print_table(ctx, group_by=group_by, sort_by=sort_by, expand=expand)
     exit_with_code(ctx)
 
 
@@ -64,10 +73,19 @@ def json(ctx: click.Context, output: pathlib.Path | None) -> None:
 
 @click.command()
 @click.pass_context
-def text(ctx: click.Context) -> None:
+@click.option(
+    "--expand",
+    "-x",
+    default=False,
+    show_envvar=True,
+    is_flag=True,
+    show_default=True,
+    help="Flag to indicate if atomic results should be shown.",
+)
+def text(ctx: click.Context, *, expand: bool) -> None:
     """ANTA command to check network state with text results."""
     _ = run_tests(ctx)
-    print_text(ctx)
+    print_text(ctx, expand=expand)
     exit_with_code(ctx)
 
 
@@ -127,8 +145,17 @@ def tpl_report(ctx: click.Context, template: pathlib.Path, output: pathlib.Path
     required=True,
     help="Path to save the report as a Markdown file",
 )
-def md_report(ctx: click.Context, md_output: pathlib.Path) -> None:
+@click.option(
+    "--expand",
+    "-x",
+    default=False,
+    show_envvar=True,
+    is_flag=True,
+    show_default=True,
+    help="Flag to indicate if atomic results should be shown.",
+)
+def md_report(ctx: click.Context, md_output: pathlib.Path, *, expand: bool) -> None:
     """ANTA command to check network state with Markdown report."""
     run_context = run_tests(ctx)
-    save_markdown_report(ctx, md_output=md_output, run_context=run_context)
+    save_markdown_report(ctx, md_output=md_output, run_context=run_context, expand=expand)
     exit_with_code(ctx)
