@@ -18,6 +18,8 @@ class AVTPath(BaseModel):
     """VRF context. Defaults to `default`."""
     avt_name: str
     """The name of the Adaptive Virtual Topology (AVT)."""
+    description: str | None = None
+    """Optional metadata describing the AVT path. Used for reporting."""
     destination: IPv4Address
     """The IPv4 address of the destination peer in the AVT."""
     next_hop: IPv4Address
@@ -30,7 +32,14 @@ class AVTPath(BaseModel):
 
         Examples
         --------
-        AVT CONTROL-PLANE-PROFILE VRF: default (Destination: 10.101.255.2, Next-hop: 10.101.255.1)
+        AVT: CONTROL-PLANE-PROFILE VRF: default Destination: 10.101.255.2 Next-hop: 10.101.255.1
 
         """
-        return f"AVT: {self.avt_name} VRF: {self.vrf} Destination: {self.destination} Next-hop: {self.next_hop}"
+        base_string = f"AVT: {self.avt_name}"
+        if self.description:
+            base_string += f" ({self.description})"
+        base_string += f" VRF: {self.vrf} Destination: {self.destination} Next-hop: {self.next_hop}"
+        if self.path_type:
+            base_string += f" Path Type: {self.path_type}"
+
+        return base_string
