@@ -16,6 +16,8 @@ class DpsPath(BaseModel):
     model_config = ConfigDict(extra="forbid")
     peer: IPv4Address
     """Static peer IPv4 address."""
+    description: str | None = None
+    """Optional metadata describing the DPS path. Used for reporting."""
     path_group: str
     """Router path group name."""
     source_address: IPv4Address
@@ -25,4 +27,5 @@ class DpsPath(BaseModel):
 
     def __str__(self) -> str:
         """Return a human-readable string representation of the DpsPath for reporting."""
-        return f"Peer: {self.peer} PathGroup: {self.path_group} Source: {self.source_address} Destination: {self.destination_address}"
+        description = f" ({self.description})" if self.description else ""
+        return f"Peer: {self.peer}{description} Path Group: {self.path_group} Source: {self.source_address} Destination: {self.destination_address}"
