@@ -3,8 +3,8 @@
 # that can be found in the LICENSE file.
 """Module related to Adaptive virtual topology tests."""
 
-# Mypy does not understand AntaTest.Input typing
-# mypy: disable-error-code=attr-defined
+# Pyright does not understand AntaTest.Input typing
+# pyright: reportAttributeAccessIssue=false
 from __future__ import annotations
 
 from typing import ClassVar
@@ -12,6 +12,7 @@ from typing import ClassVar
 from anta.decorators import skip_on_platforms
 from anta.input_models.avt import AVTPath
 from anta.models import AntaCommand, AntaTemplate, AntaTest
+from anta.result_manager.models import AntaTestStatus
 from anta.tools import get_value
 
 
@@ -102,6 +103,7 @@ class VerifyAVTSpecificPath(AntaTest):
 
     categories: ClassVar[list[str]] = ["avt"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show adaptive-virtual-topology path", revision=1)]
+    _atomic_support: ClassVar[bool] = True
 
     class Input(AntaTest.Input):
         """Input model for the VerifyAVTSpecificPath test."""
@@ -120,11 +122,14 @@ class VerifyAVTSpecificPath(AntaTest):
 
         command_output = self.instance_commands[0].json_output
         for avt_path in self.inputs.avt_paths:
-            if (path_output := get_value(command_output, f"vrfs.{avt_path.vrf}.avts.{avt_path.avt_name}.avtPaths")) is None:
-                self.result.is_failure(f"{avt_path} - No AVT path configured")
-                return
+            # Atomic result
+            result = self.result.add(description=str(avt_path), status=AntaTestStatus.SUCCESS)
 
-            path_found = path_type_found = False
+            if (path_output := get_value(command_output, f"vrfs.{avt_path.vrf}.avts.{avt_path.avt_name}.avtPaths")) is None:
+                result.is_failure("No AVT path configured")
+                continue
+
+            path_found = False
 
             # Check each AVT path
             for path, path_data in path_output.items():
@@ -135,22 +140,17 @@ class VerifyAVTSpecificPath(AntaTest):
                 if not avt_path.path_type:
                     path_found = all([dest == str(avt_path.destination), nexthop == str(avt_path.next_hop)])
 
-                else:
-                    path_type_found = all([dest == str(avt_path.destination), nexthop == str(avt_path.next_hop), path_type == avt_path.path_type])
-                    if path_type_found:
-                        path_found = True
-                        # Check the path status and type against the expected values
-                        valid = get_value(path_data, "flags.valid")
-                        active = get_value(path_data, "flags.active")
-                        if not all([valid, active]):
-                            self.result.is_failure(f"{avt_path} - Incorrect path {path} - Valid: {valid} Active: {active}")
+                elif all([dest == str(avt_path.destination), nexthop == str(avt_path.next_hop), path_type == avt_path.path_type]):
+                    path_found = True
+                    # Check the path status and type against the expected values
+                    valid = get_value(path_data, "flags.valid")
+                    active = get_value(path_data, "flags.active")
+                    if not all([valid, active]):
+                        result.is_failure(f"Incorrect path {path} - Valid: {valid} Active: {active}")
 
             # If no matching path found, mark the test as failed
             if not path_found:
-                if avt_path.path_type and not path_type_found:
-                    self.result.is_failure(f"{avt_path} Path Type: {avt_path.path_type} - Path not found")
-                else:
-                    self.result.is_failure(f"{avt_path} - Path not found")
+                result.is_failure("Path not found")
 
 
 class VerifyAVTRole(AntaTest):
