@@ -3,8 +3,8 @@
 # that can be found in the LICENSE file.
 """Module related to the hardware or environment tests."""
 
-# Mypy does not understand AntaTest.Input typing
-# mypy: disable-error-code=attr-defined
+# Pyright does not understand AntaTest.Input typing
+# pyright: reportAttributeAccessIssue=false
 from __future__ import annotations
 
 from collections import defaultdict
@@ -16,6 +16,7 @@ from anta.custom_types import ModuleStatus, Percent, PositiveInteger, PowerSuppl
 from anta.decorators import skip_on_platforms
 from anta.input_models.hardware import AdverseDropThresholds, HardwareInventory, PCIeThresholds
 from anta.models import AntaCommand, AntaTemplate, AntaTest
+from anta.result_manager.models import AntaTestStatus
 
 if TYPE_CHECKING:
     from collections.abc import Callable
@@ -43,6 +44,7 @@ class VerifyTransceiversManufacturers(AntaTest):
 
     categories: ClassVar[list[str]] = ["hardware"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaCommand(command="show inventory", revision=2)]
+    _atomic_support: ClassVar[bool] = True
 
     class Input(AntaTest.Input):
         """Input model for the VerifyTransceiversManufacturers test."""
@@ -56,16 +58,18 @@ class VerifyTransceiversManufacturers(AntaTest):
         """Main test function for VerifyTransceiversManufacturers."""
         self.result.is_success()
         command_output = self.instance_commands[0].json_output
-        for interface, value in command_output["xcvrSlots"].items():
+
+        for port, value in command_output["xcvrSlots"].items():
+            # Atomic result
+            result = self.result.add(description=f"Port: {port}", status=AntaTestStatus.SUCCESS)
+
             if not (mfg_name := value["mfgName"]):
                 # Cover transceiver issues like 'xcvr-unsupported'
-                self.result.is_failure(f"Interface: {interface} - Manufacturer name is not available - This may indicate an unsupported or faulty transceiver")
+                result.is_failure("Manufacturer name is not available - This may indicate an unsupported or faulty transceiver")
                 continue
 
             if mfg_name not in self.inputs.manufacturers:
-                self.result.is_failure(
-                    f"Interface: {interface} - Transceiver is from unapproved manufacturers - Expected: {', '.join(self.inputs.manufacturers)} Actual: {mfg_name}"
-                )
+                result.is_failure(f"Transceiver is from unapproved manufacturers - Expected: {', '.join(self.inputs.manufacturers)} Actual: {mfg_name}")
 
 
 class VerifyTemperature(AntaTest):
