@@ -5,14 +5,15 @@
 
 from __future__ import annotations
 
-# Mypy does not understand AntaTest.Input typing
-# mypy: disable-error-code=attr-defined
+# Pyright does not understand AntaTest.Input typing
+# pyright: reportAttributeAccessIssue=false
 from datetime import datetime, timezone
 from typing import ClassVar
 
 from anta.custom_types import PositiveInteger
 from anta.input_models.security import ACL, APISSLCertificate, IPSecPeer, IPSecPeers
 from anta.models import AntaCommand, AntaTemplate, AntaTest
+from anta.result_manager.models import AntaTestStatus
 from anta.tools import get_item, get_value
 
 
@@ -443,6 +444,9 @@ class VerifyAPISSLCertificate(AntaTest):
 class VerifyBannerLogin(AntaTest):
     """Verifies the login banner of a device.
 
+    PyYAML does not preserve leading spaces so the recommendation is to use the following syntax:
+    `|2+` to indicate where the banner starts and to preserve any new line at the end.
+
     Expected Results
     ----------------
     * Success: The test will pass if the login banner matches the provided input.
@@ -453,10 +457,11 @@ class VerifyBannerLogin(AntaTest):
     ```yaml
     anta.tests.security:
       - VerifyBannerLogin:
-          login_banner: |
+          login_banner: |2+
             # Copyright (c) 2023-2024 Arista Networks, Inc.
             # Use of this source code is governed by the Apache License 2.0
             # that can be found in the LICENSE file.
+
     ```
     """
 
@@ -477,15 +482,17 @@ class VerifyBannerLogin(AntaTest):
             self.result.is_failure("Login banner is not configured")
             return
 
-        # Remove leading and trailing whitespaces from each line
-        cleaned_banner = "\n".join(line.strip() for line in self.inputs.login_banner.split("\n"))
-        if login_banner != cleaned_banner:
-            self.result.is_failure(f"Incorrect login banner configured - Expected: {cleaned_banner} Actual: {login_banner}")
+        if login_banner != self.inputs.login_banner:
+            self.result.is_failure(f"Incorrect login banner configured - Expected: '{self.inputs.login_banner}' Actual: '{login_banner}'")
 
 
 class VerifyBannerMotd(AntaTest):
     """Verifies the motd banner of a device.
 
+    PyYAML does not preserve leading spaces so the recommendation is to use the following syntax:
+    `|2+` to indicate where the banner starts and to preserve any new line at the end.
+
+
     Expected Results
     ----------------
     * Success: The test will pass if the motd banner matches the provided input.
@@ -496,7 +503,7 @@ class VerifyBannerMotd(AntaTest):
     ```yaml
     anta.tests.security:
       - VerifyBannerMotd:
-          motd_banner: |
+          motd_banner: |2+
             # Copyright (c) 2023-2024 Arista Networks, Inc.
             # Use of this source code is governed by the Apache License 2.0
             # that can be found in the LICENSE file.
@@ -520,10 +527,8 @@ class VerifyBannerMotd(AntaTest):
             self.result.is_failure("MOTD banner is not configured")
             return
 
-        # Remove leading and trailing whitespaces from each line
-        cleaned_banner = "\n".join(line.strip() for line in self.inputs.motd_banner.split("\n"))
-        if motd_banner != cleaned_banner:
-            self.result.is_failure(f"Incorrect MOTD banner configured - Expected: {cleaned_banner} Actual: {motd_banner}")
+        if motd_banner != self.inputs.motd_banner:
+            self.result.is_failure(f"Incorrect MOTD banner configured - Expected: '{self.inputs.motd_banner}' Actual: '{motd_banner}'")
 
 
 class VerifyIPv4ACL(AntaTest):
@@ -678,6 +683,7 @@ class VerifySpecificIPSecConn(AntaTest):
 
     categories: ClassVar[list[str]] = ["security"]
     commands: ClassVar[list[AntaCommand | AntaTemplate]] = [AntaTemplate(template="show ip security connection vrf {vrf} path peer {peer}", revision=2)]
+    _atomic_support: ClassVar[bool] = True
 
     class Input(AntaTest.Input):
         """Input model for the VerifySpecificIPSecConn test."""
@@ -703,17 +709,20 @@ class VerifySpecificIPSecConn(AntaTest):
 
             # Check if IPv4 security connection is configured
             if not conn_output:
-                self.result.is_failure(f"{input_peer} - Not configured")
+                # Atomic result
+                self.result.add(description=str(input_peer), status=AntaTestStatus.FAILURE, messages=["Not configured"])
                 continue
 
             # If connection details are not provided then check all connections of a peer
             if conn_input is None:
                 for conn_data in conn_output.values():
                     state = next(iter(conn_data["pathDict"].values()))
+                    # Atomic result
+                    source = conn_data.get("saddr")
+                    destination = conn_data.get("daddr")
+                    result = self.result.add(description=f"{input_peer} Source: {source} Destination: {destination}", status=AntaTestStatus.SUCCESS)
                     if state != "Established":
-                        source = conn_data.get("saddr")
-                        destination = conn_data.get("daddr")
-                        self.result.is_failure(f"{input_peer} Source: {source} Destination: {destination} - Connection down - Expected: Established Actual: {state}")
+                        result.is_failure(f"Connection down - Expected: Established Actual: {state}")
                 continue
 
             # Create a dictionary of existing connections for faster lookup
@@ -724,14 +733,15 @@ class VerifySpecificIPSecConn(AntaTest):
             for connection in conn_input:
                 source_input = str(connection.source_address)
                 destination_input = str(connection.destination_address)
-
+                # Atomic result
+                result = self.result.add(description=f"{input_peer} {connection}", status=AntaTestStatus.SUCCESS)
                 if (source_input, destination_input, vrf) in existing_connections:
                     existing_state = existing_connections[(source_input, destination_input, vrf)]
                     if existing_state != "Established":
                         failure = f"Expected: Established Actual: {existing_state}"
-                        self.result.is_failure(f"{input_peer} Source: {source_input} Destination: {destination_input} - Connection down - {failure}")
+                        result.is_failure(f"Connection down - {failure}")
                 else:
-                    self.result.is_failure(f"{input_peer} Source: {source_input} Destination: {destination_input} - Connection not found.")
+                    result.is_failure("Connection not found")
 
 
 class VerifyHardwareEntropy(AntaTest):
