@@ -52,7 +52,7 @@ def test_anta_nrfu_table(click_runner: CliRunner) -> None:
     """Test anta nrfu, catalog is given via env."""
     result = click_runner.invoke(anta, ["nrfu", "table"])
     assert result.exit_code == ExitCode.OK
-    assert "leaf1  │ VerifyEOSVersion │ success" in result.output
+    assert "leaf1  │ VerifyEOSVersion │ Verifies the EOS version of the device." in result.output
 
 
 def test_anta_nrfu_table_group_by_device(click_runner: CliRunner) -> None:
@@ -69,6 +69,14 @@ def test_anta_nrfu_table_group_by_test(click_runner: CliRunner) -> None:
     assert "Summary per test" in result.output
 
 
+def test_anta_nrfu_table_expand(click_runner: CliRunner) -> None:
+    """Test anta nrfu, catalog is given via env."""
+    with patch("anta.reporter.ReportTable.generate_expanded") as mocked_generate_expanded:
+        result = click_runner.invoke(anta, ["nrfu", "table", "--expand"])
+    assert result.exit_code == ExitCode.OK
+    mocked_generate_expanded.assert_called_once()
+
+
 def test_anta_nrfu_text(click_runner: CliRunner) -> None:
     """Test anta nrfu, catalog is given via env."""
     result = click_runner.invoke(anta, ["nrfu", "text"])
@@ -89,6 +97,19 @@ def test_anta_nrfu_text_multiple_failures(click_runner: CliRunner) -> None:
     )
 
 
+def test_anta_nrfu_text_expand(click_runner: CliRunner) -> None:
+    """Test anta nrfu, catalog is given via env."""
+    result = click_runner.invoke(anta, ["nrfu", "text", "--expand"], env={"ANTA_CATALOG": str(DATA_DIR / "test_atomic.yml")})
+    assert result.exit_code == ExitCode.TESTS_FAILED
+    assert (
+        """leaf1 :: VerifyReachability :: FAILURE
+    Destination 10.255.255.0 from 10.255.255.1 in VRF default :: SUCCESS
+    Destination 10.255.255.2 from 10.255.255.3 in VRF default :: FAILURE
+      Packet loss detected - Transmitted: 1 Received: 2"""
+        in result.output
+    )
+
+
 def test_anta_nrfu_json(click_runner: CliRunner) -> None:
     """Test anta nrfu, catalog is given via env."""
     result = click_runner.invoke(anta, ["nrfu", "json"])
@@ -175,6 +196,37 @@ def test_anta_nrfu_md_report(click_runner: CliRunner, tmp_path: Path) -> None:
     assert md_output.exists()
 
 
+def test_anta_nrfu_md_report_expand(click_runner: CliRunner, tmp_path: Path) -> None:
+    """Test anta nrfu md-report."""
+    md_output = tmp_path / "test.md"
+    result = click_runner.invoke(anta, ["nrfu", "md-report", "--md-output", str(md_output), "--expand"])
+    assert result.exit_code == ExitCode.OK
+    assert "Markdown report saved to" in result.output
+    assert md_output.exists()
+
+    with md_output.open("r", encoding="utf-8") as f:
+        content = f.read()
+
+        target_header = '## 📉 Test Results Summary <a id="test-results-summary"></a>'
+        target_note = (
+            ">💡 **Note:** This report was generated with **Expanded Results** enabled. "
+            "The summary sections below aggregate results at the test level, so individual "
+            "checks (atomic results) are not counted in these totals."
+        )
+
+        assert target_header in content
+
+        # Find the position of the header
+        header_index = content.find(target_header)
+
+        # Create a slice of the content starting from the header
+        # This ensures we are only looking "under" or "after" that section title
+        content_after_header = content[header_index:]
+
+        # Assert the note exists in that specific slice
+        assert target_note in content_after_header
+
+
 def test_anta_nrfu_md_report_failure(click_runner: CliRunner, tmp_path: Path) -> None:
     """Test anta nrfu md-report failure."""
     md_output = tmp_path / "test.md"
@@ -213,10 +265,10 @@ def test_anta_nrfu_md_report_with_hide(click_runner: CliRunner, tmp_path: Path)
     row_count = 0
     lines = content.splitlines()
 
-    idx = lines.index("## Test Results")
+    idx = lines.index('## 🧪 Test Results <a id="test-results"></a>')
 
     for line in lines[idx + 1 :]:
-        if line.startswith("|") and "---" not in line:
+        if line.startswith("|") and ":-" not in line:
             row_count += 1
     # Reducing the row count by 1, as above conditions counts the TABLE_HEADING
     assert (row_count - 1) == 0
@@ -227,4 +279,8 @@ def test_anta_nrfu_table_sort(click_runner: CliRunner) -> None:
     result = click_runner.invoke(
         anta, ["nrfu", "table", "--sort-by", "name", "--sort-by", "test"], env={"ANTA_CATALOG": str(DATA_DIR / "test_catalog_table_sort.yml")}
     )
-    assert "spine1 │ VerifyInterfacesSpeed │ failure" in result.output.splitlines()[-3]
+    target_line = result.output.splitlines()[-3]
+
+    # Check that device, test, description and status exist on the line
+    # The regex ensures they appear in that specific order
+    assert re.search(r"spine1.*VerifyInterfacesSpeed.*Verifies the speed, lanes, auto-negotiation.*failure", target_line)
