@@ -158,7 +158,7 @@ class TestAntaRunner:
         ctx = await runner.run(inventory, catalog, filters=filters, dry_run=True)
 
         # Gather the warning message
-        warning_msg = None
+        msg = None
         if expected_devices == 0:
             msg = "The inventory is empty after filtering by tags/devices. "
             if filters.devices:
@@ -174,7 +174,7 @@ class TestAntaRunner:
                 msg += f"Tags filter: {', '.join(sorted(filters.tags))}. "
             msg += "Exiting ..."
 
-        if warning_msg is not None:
+        if msg is not None:
             assert msg in ctx.warnings_at_setup
             assert msg in caplog.messages
 
